@@ -43,7 +43,7 @@ class GlossaryEntry;
 
     private:
       struct Private;
-      Private *d;
+      Private *const d;
   };
 
 }
